# Gamma Desk

![Gamma Desk Logo](https://github.com/thocoo/gamma-desk/raw/main/gdesk/resources/logo/logo_128px.png)

A Python work environment with image viewers & Plots

# Screen shots

![Screen Shot 1](https://github.com/thocoo/gamma-desk/raw/main/doc/sphinx/source/figures/screenshot_01.jpg)

# Features

- Multiple Consoles in the Gui Process
- Multiple Child Process Consoles
- More advanced auto command completion
- Matplotlib integration
- Image Viewers using QT Painter
- Image histograms
- Image column & row profiles
- Advanced window & panel docking
- Linked Image Viewers

# Usage

python -m gdesk

# More documentation

[Program Help](https://thocoo.github.io/gdesk-data/docs)

[Source Code](https://github.com/thocoo/gamma-desk)

# Dependencies 

`numpy`
`matplotlib`
`scipy`
`PySide2`
`qtpy`
`psutils`
`pyzmq`
`ninja2`
`toml`
